package com.zehong.system.service;

import java.util.List;
import com.zehong.system.domain.ReceivedNbFailureHistory;

/**
 * 获取NB码失败记录Service接口
 * 
 * @author zehong
 * @date 2026-07-18
 */
public interface IReceivedNbFailureHistoryService 
{
    /**
     * 查询获取NB码失败记录
     * 
     * @param id 获取NB码失败记录ID
     * @return 获取NB码失败记录
     */
    public ReceivedNbFailureHistory selectReceivedNbFailureHistoryById(Long id);

    /**
     * 查询获取NB码失败记录列表
     * 
     * @param receivedNbFailureHistory 获取NB码失败记录
     * @return 获取NB码失败记录集合
     */
    public List<ReceivedNbFailureHistory> selectReceivedNbFailureHistoryList(ReceivedNbFailureHistory receivedNbFailureHistory);

    /**
     * 新增获取NB码失败记录
     * 
     * @param receivedNbFailureHistory 获取NB码失败记录
     * @return 结果
     */
    public int insertReceivedNbFailureHistory(ReceivedNbFailureHistory receivedNbFailureHistory);

    /**
     * 修改获取NB码失败记录
     * 
     * @param receivedNbFailureHistory 获取NB码失败记录
     * @return 结果
     */
    public int updateReceivedNbFailureHistory(ReceivedNbFailureHistory receivedNbFailureHistory);

    /**
     * 批量删除获取NB码失败记录
     * 
     * @param ids 需要删除的获取NB码失败记录ID
     * @return 结果
     */
    public int deleteReceivedNbFailureHistoryByIds(Long[] ids);

    /**
     * 删除获取NB码失败记录信息
     * 
     * @param id 获取NB码失败记录ID
     * @return 结果
     */
    public int deleteReceivedNbFailureHistoryById(Long id);
}
